import Qt 4.7
import "../common/widgets" as Widgets
import "../common/Common.js" as Common
import "../common/EnumHelper.js" as EnumHelper

ActivationBasePage
{
	function showTrialBlock()
	{
		return !context.IsActiveLicenseExist && !context.IsTrialPeriodOver && EnumHelper.getKey(context, "ActivationReason") != "ActivationReason_FromKAVToCommercialKIS"
	}
	
	objectName: "activationPageEdition"
	headerString:			showTrialBlock() ? context.Localize("SelectionOfActivationTypeHeader") : context.Localize("ProlongationOfActivationHeader")
	nextButtonEnabled:		(selectionForTrialLicense.visible && selectionForTrialLicense.checked) || checkValidityOfActivationCode()
	
	function checkValidityOfActivationCode()
	{
		if (serialNumber.isFull())
		{
			var valid = context.IsActivationCodeValid(serialNumber.serialNumberText);
			if (valid)
			{
				activationCodeInputErrorBlock.visible = false;
				serialNumber.state = "";
			}
			else
			{
				activationCodeInputErrorBlock.visible = true;
				serialNumber.state = "highlight";
			}
			return valid;
		}
		activationCodeInputErrorBlock.visible = false;
		serialNumber.state = "";
		return false;
	}
	
	Widgets.RadioGroup		{id: selectionForActivationType}

	Widgets.RadioButton
	{
		id:					selectionForCommercialLicense
		objectName: "selectionForCommercialLicense"
		anchors.top:		parent.top
		anchors.left:		parent.left
		color: 				"transparent"
		horizontalMargin:	7
		textfont:			activationWizard.fontStyles.checkBoxTextNormal
		text:				context.Localize("SelectCommercialActivation")
		checked:			context ? EnumHelper.getKey(context, "LicenseType") == "LicenseTypeCommercial" : false
		group:				selectionForActivationType
		visible:			showTrialBlock()
		textVerticalMargin: -1
		onCheckedChanged:	
		{
			if (checked)
			{
				context.LicenseType = "LicenseTypeCommercial";
				serialNumber.setFocus();
			}
			else
			{
				serialNumber.setFocusOff();
			}
		}
	}
	Item
	{
		id: commercialActivationBlock
		objectName: "commercialActivationBlock"
		anchors.top:		selectionForCommercialLicense.visible ? selectionForCommercialLicense.bottom : parent.top
		anchors.topMargin:	selectionForCommercialLicense.visible ? 18 : 0
		anchors.left:		parent.left
		anchors.leftMargin: selectionForCommercialLicense.visible ? 24 : 0
		anchors.right:		parent.right
		height: childrenRect.height
		Column
		{
			id:					serialNumberBlock
			objectName: "serialNumberBlock"
			width:				parent.width

			spacing:			12

			Row
			{
				spacing: 10
				Text
				{
					id:		textForSerialNumber
					text:	context.Localize("EnterActivationCode")
					font:	activationWizard.fontStyles.masterOfActivationButtonsNormalText
				}
				Widgets.Hyperlink
				{
					id: 	helpTextForSerialNumber
					text:	context.Localize("SerialNumberHelpString")

					onClicked: context.ShowActivationCodeHelp();
				}
			}
			Item
			{
				anchors.left:parent.left
				anchors.right:parent.right
			
				height:serialNumber.height
				
				SerialNumber
				{
					id: serialNumber
					property string activationCode: context.ActivationCode
				
					Component.onCompleted:
					{
						serialNumber.setFocus();
					}
					onActivationCodeChanged:
					{
						serialNumberText = activationCode;
					}
					onInputActiveFocusChanged:
					{
						if (inputActiveFocus)
							selectionForCommercialLicense.checked = true;
					}
				}
				Binding {target: context; property: "ActivationCode"; value: serialNumber.serialNumberText}
				
				Item
				{
					id: activationCodeInputErrorBlock
					
					visible: false
					
					anchors.left: serialNumber.right; anchors.leftMargin:10
					anchors.right: parent.right;
					anchors.verticalCenter: serialNumber.verticalCenter
					height:parent.height + 10

					Image
					{
						id: warningIcon
						anchors.left: parent.left; 
						anchors.verticalCenter: parent.verticalCenter
						source: "../common/images/ico_warning_16.png"
					}
					Text
					{
						id: textForInputError
						
						anchors.left: warningIcon.right; anchors.leftMargin: 5
						anchors.right: parent.right;
					
						height:parent.height

						anchors.verticalCenter: parent.verticalCenter
						
						verticalAlignment:	Text.AlignVCenter
						
						text:	context.Localize("ActivationCodeInputError")
						font:	activationWizard.fontStyles.masterOfActivationButtonsNormalText
						wrapMode: Text.Wrap
					}
				}
			}
		}
		Column
		{
			id: purchaseBlock
			anchors.top: serialNumberBlock.bottom
			anchors.topMargin: 18
			anchors.left: serialNumberBlock.left
			width: parent.width
			height: childrenRect.height
			spacing: 12

			Text
			{
				id:			textForPurchasingLicense
				text:		context.Localize("TextForPurchasingLicenseWithTrial")
				width:		parent.width
				wrapMode:	Text.Wrap
				font:		activationWizard.fontStyles.masterOfActivationButtonsNormalText
			}
			Widgets.GrayButton
			{
				id:					buttonForPurchasingLicense
				objectName: "buttonForPurchasingLicense"
				text:				context.Localize("ButtonTextForPurchasingLicense")
				onClicked: context.PurchaseProduct(Common.buildPath(parent)+"."+buttonForPurchasingLicense.objectName, false);
			}
		}
	}
	Item
	{
		objectName: "forTrialLicense"
		anchors.top: commercialActivationBlock.bottom
		anchors.topMargin: 30
		anchors.left:			parent.left
		anchors.right:			parent.right
		visible:				showTrialBlock()
		Widgets.RadioButton
		{
			id:						selectionForTrialLicense
			objectName: "selectionForTrialLicense"
			group:					selectionForActivationType
			text:					context.Localize("SelectionTrialLicense")
			horizontalMargin:		7
			color: 					"transparent"
			checked:				context ? EnumHelper.getKey(context, "LicenseType") == "LicenseTypeTrial" : false
			textfont:				activationWizard.fontStyles.checkBoxTextNormal
			anchors.left:			parent.left
			anchors.top:			parent.top
			textVerticalMargin: -1

			onCheckedChanged:	
			{
				if (checked)
					context.LicenseType = "LicenseTypeTrial";
			}
		}
		Text
		{
			id:					textForTrialLicense
			text:				context.Localize("TextForTrialLicense")
			anchors.left:		parent.left
			anchors.leftMargin: 24
			anchors.right:		parent.right
			anchors.top:		selectionForTrialLicense.bottom
			anchors.topMargin:	6
			font:				activationWizard.fontStyles.masterOfActivationButtonsNormalText
			wrapMode:			Text.Wrap
		}
	}

	function onNext()
	{
		context.StartActivation();
	}
	function onHelp()
	{
		Help.Show(44437);
	}
}

