import Qt 4.7
import "../common/widgets" as Widgets

Rectangle
{
	id: 				serialNumberElement
	border.color:		"black"
	border.width:		1
	width:				serialNumberObject.elementWidth
	height:				serialNumberObject.elementHeight

	property alias inputFocus:		textInput.focus
	property alias inputActiveFocus: textInput.activeFocus
	property alias text:			textInput.text
	property int maxSymbolCount:	serialNumberObject.maxSymbolCount

	property variant serialNumberObject: serialNumber
	property variant nextElement
	property variant previousElement

	function setInputFocus()
	{
		textInput.forceActiveFocus();
	}
	function insertText(overText)
	{
		textInput.updateText(overText + text);
	}
	function changeCursorPosition(newPosition)
	{
		if (nextElement && (newPosition >= maxSymbolCount))
			nextElement.changeCursorPosition(newPosition - maxSymbolCount);
		else
			setFocus(false, Math.min(newPosition, maxSymbolCount));
	}
	function setFocus(selectText, newPosition)
	{
		textInput.focus = 1;
		if (selectText)
			textInput.selectAll();
		else
			textInput.cursorPosition = Math.min(newPosition, maxSymbolCount);
	}

	Widgets.EditableMessageArea{anchors.fill: textInput}

	TextInput
	{
		id: 							textInput
		font:							serialNumberObject.fontStyles.serialNumberFont
		property alias maxSymbolCount:	serialNumberElement.maxSymbolCount

		anchors.leftMargin:					7
		anchors.rightMargin:				5
		anchors.left:						parent.left
		anchors.right:						parent.right
		anchors.verticalCenter:				parent.verticalCenter
		anchors.verticalCenterOffset:		2
		selectByMouse:						true
		cursorVisible:						activeFocus
		property bool selfUpdatingText: 	false
		validator: 							RegExpValidator {regExp: RegExp("[a-zA-Z0-9- ]*[\n\r]*")}

		function updateText(newText)
		{
			selfUpdatingText = true;
			text = newText;
			selfUpdatingText = false;
		}
		function updateCursorPosition(position)
		{
			if (textInput.focus)
				changeCursorPosition(position);
		}
		Keys.onPressed:
		{
			if (((event.key == Qt.Key_Tab) || ((event.key == Qt.Key_Right) && (textInput.cursorPosition == text.length))) && serialNumberElement.nextElement)
			{
				event.accepted = true;
				if (nextElement)
					nextElement.setFocus(true, 0);
			}
			else if (((event.key == Qt.Key_Backtab) || ((event.key == Qt.Key_Left) && (textInput.cursorPosition == 0))) && serialNumberElement.previousElement)
			{
				event.accepted = true;
				if (previousElement)
					previousElement.setFocus(true, serialNumberElement.maxSymbolCount);
			}
			else if ((event.text == "-") || (event.text == " "))
			{
				event.accepted = true;
			}
			else if ((event.key == Qt.Key_Backspace) && (textInput.cursorPosition == 0) && previousElement)
			{
				previousElement.setFocus(true, serialNumberElement.maxSymbolCount);
				event.accepted = true;
			}
		}
		onTextChanged: 
		{
			var processingText = textInput.text.replace(RegExp("[- ]+"), "").replace(RegExp("[\n\r]+.*"), "").toLocaleUpperCase();
			var currentPosition = textInput.cursorPosition;
			if (processingText.length > maxSymbolCount)
			{
				var overText = processingText.substr(maxSymbolCount, processingText.length - maxSymbolCount);
				if (nextElement && overText)
				{
					nextElement.insertText(overText);
					updateCursorPosition(currentPosition);
				}
				textInput.updateText(processingText.substr(0, maxSymbolCount));
			}
			else if (processingText != textInput.text)
				textInput.updateText(processingText);

			if (!selfUpdatingText)
			{
				updateCursorPosition(currentPosition);
				changeSerialNumberText();
			}
		}
	}
}

