import Qt 4.7
import "../fonts" as Fonts
import "../widgets" as Widgets
import "../Common.js" as Common
import "../EnumHelper.js" as EnumHelper

Item
{
	id: pageFrame
	objectName: "pageFrame"

	property variant commonFontStyles: Fonts.Common{}
        property variant fontFontStyle: Fonts.Fonts{}

	// For ViewManager...
	property int duration: 0
	clip: true

	width:  frameImage.width
	height: frameImage.height

	property bool hasBanner: true

	property alias minimizeButtonEnabled: windowButtons.minimizeButtonEnabled
	property alias minimizeButtonVisible: windowButtons.minimizeButtonVisible

	property alias backButtonVisible:	backButton.visible
	property alias backButtonEnabled:	backButton.enabled
	property alias backButtonText:		backButton.text

	property alias nextButtonVisible:	nextButton.visible
	property alias nextButtonEnabled:	nextButton.enabled
	property alias nextButtonText:		nextButton.text
	property alias nextButtonStyle:		nextButton.style
	property alias nextButtonIconImage:	nextButton.iconImage
	property alias nextButtonWidth:		nextButton.buttonWidth

	property alias cancelButtonVisible:	cancelButton.visible
	property alias cancelButtonEnabled:	cancelButton.enabled
	property alias cancelButtonText:	cancelButton.text

	property alias helpButtonVisible: 	helpButton.visible
	property alias windowDescriptionText:	windowDescription.text

	property alias footerAnchors: backnextcancelButtons.anchors

	signal help
	signal close
	signal back
	signal next(string objectPath)
	signal cancel

	Rectangle
	{
		id: rect
		anchors
		{
			fill: parent
            topMargin: 29
            leftMargin: 9
            rightMargin: 9
            bottomMargin: 44
		}
		color: "white"
	}

	Image
	{
		visible: pageFrame.hasBanner
		source: "../images/secondary/wizard_bg.png"
		anchors.left: rect.left
        anchors.leftMargin: 1
        anchors.top: rect.top
        anchors.topMargin: 1
		anchors.bottom : parent.bottom
        anchors.bottomMargin:44
		smooth: true
		Image
		{
			function getProductTypeImage(context, productType)
			{
				return EnumHelper.convert(context, productType, {
					"KasperskyInternetSecurity" : "../images/secondary/kis_logo.png",
					"KasperskyAntiVirus" : "../images/secondary/kav_logo.png",
					"KasperskyAntiVirusForWorkstation" : "",
					"KasperskyAntiVirusForFileServer" : "",
					"KasperskyAntiVirusTool" : "",
					"KasperskyRescueDisk" : "",
					"Unknown" : ""});
			}
			source: getProductTypeImage(MainWindow, "productType")
		}
		Image
		{
			source: "../images/secondary/kaspersky_logo.png"
			y: 120
		}
	}

	BorderImage
	{
		id: frameImage
		source: "../images/secondary/secondary_window_frame.png"
		border
		{
			left: 100
			right: 100
			top: 100
			bottom: 100
		}
		Widgets.DPIScaler { changeSize: true }
	}

	SecondaryWindowButtons { id: windowButtons; onClose: pageFrame.close(); }

	Item
	{
		id: captionArea
        height: 29
		width: parent.width
	}

	Image
	{
		id: windowIcon
		anchors.left: captionArea.left
        anchors.leftMargin: 10
		anchors.verticalCenter: captionArea.verticalCenter
		source: "../images/window/ico_k_16.png"
	}

	Text
	{
		id:						windowDescription
                anchors.left: windowIcon.right
                anchors.leftMargin: 4
                anchors.right: captionArea.right
                anchors.verticalCenter: captionArea.verticalCenter
                anchors.verticalCenterOffset: 1
                font: commonFontStyles.standardWindowCaptionFont
	}

    Widgets.HelpButton
	{
		id:						helpButton
        context: MainWindow
		anchors.left:			parent.left
        anchors.leftMargin:		10
		anchors.bottom:			parent.bottom
        anchors.bottomMargin:	13
        onClicked: pageFrame.help()
	}
	Row
	{
		id: backnextcancelButtons
		objectName: "backnextcancelButtons"
                spacing: 7
		anchors.bottom:	pageFrame.bottom
                anchors.bottomMargin: 7
		anchors.right: pageFrame.right;
                anchors.rightMargin: 10

		DPIScaler { id: dpiScaler }
		property real buttonWidth: 100 * dpiScaler.factor

		Widgets.GrayButton
		{
			id:					backButton
			text:				context.Localize("BackButton")
			buttonWidth:		backnextcancelButtons.buttonWidth
			visible:			false
			onClicked:			pageFrame.back();
		}
		Widgets.GrayButton
		{
			id:					nextButton
			text:				context.Localize("NextButton")
			buttonWidth:		backnextcancelButtons.buttonWidth
			visible:			false
			onClicked:			pageFrame.next(Common.buildPath(parent)+".NextButton");
		}
		Widgets.GrayButton
		{
			id:					cancelButton
			text:				context.Localize("Cancel")
			buttonWidth:		backnextcancelButtons.buttonWidth
			onClicked:			pageFrame.cancel()
		}
	}
}
