import Qt 4.7
import "../common/widgets" as Widgets
import "../common/Common.js" as Common
import "../common/fonts" as Fonts
import "../common/EnumHelper.js" as EnumHelper

Widgets.BaseButton
{
    signal problemListButtonPressed

    id: dashboard
    objectName: "Dashboard";
    property int tabOrder: 201

    onClicked: dashboard.problemListButtonPressed()

    property variant fontStyles: Fonts.Fonts{}
    property variant context: MainWindow.dashboard

    BorderImage
    {
        id: image;
        anchors.fill:parent
        anchors.topMargin: -15 // dashboard picture shadow margin
        anchors.bottomMargin: -15
        anchors.leftMargin: -15
        anchors.rightMargin: -15
        border
        {
            left:50;
            right:50;
            top:50;
            bottom:50
        }
        source: dashboard.selectValue("", "image://preload/common/images/main_window/contentarea_mainscreen.png",
            "../common/images/main_window/contentarea_mainscreen_hover.png",
            "../common/images/main_window/contentarea_mainscreen_pressed.png")
    }

    Widgets.BaseButton
    {
        id: buyButton
        objectName: "buyButton"
        property int tabOrder: 202
        property variant enumValue : context.BuyRenewType
        onEnumValueChanged: { visible = EnumHelper.getKey(context, "BuyRenewType") != "NoButton"; }
        anchors.right: parent.right
        anchors.top: parent.top
        height: 36
        width: Math.max(row.width, 130)
        BorderImage
        {
            anchors.fill: parent
            border.left: 24
            border.right: 10
            source: buyButton.selectValue("", "image://preload/common/images/main_window/buy_normal.png", "../common/images/main_window/buy_hover.png", "../common/images/main_window/buy_pressed.png");
        }
        Row
        {
            id: row
            anchors.centerIn: parent
            Item { width: 25; height: text.height }
            Text
            {
                id: text;
                text: context.BuyRenewButtonName
                font.family: "FranklinGothicMediCondTT"
                font.pointSize: 11
                style: Text.Sunken
                color: "#ffffff"
                styleColor: "#566f90"
            }
            Item { width: 15; height: text.height }
        }
        onClicked:
        {
			if(context.BuyRenewAction != undefined)
				context.BuyRenewAction.Invoke(Common.buildPath(parent)+"."+buyButton.objectName);
        }
    }

    function getProductStateImage(object, propertyName)
    {
        return EnumHelper.convert(object, propertyName, {
                        "Unknown":"",
                        "Info":"image://preload/common/images/main_window/computer_ok.png",
                        "Warning":"image://preload/common/images/main_window/computer_problem.png",
                        "Critical":"image://preload/common/images/main_window/computer_risk.png"});
    }

    Image
    {
        id: statusImage
        anchors.verticalCenter: parent.verticalCenter
        Widgets.DPIScaler { id: dpiScaler }
        anchors.verticalCenterOffset: 15 * dpiScaler.factor
        x : 35
        Widgets.DPIScaler{changeSize:true; changeX:true}
        source: getProductStateImage(context, "ProductState")
        smooth: true
    }

    Text
    {
        id: stateText
        objectName: "ProductState";
        anchors.left : statusImage.right
        anchors.leftMargin : 25
        anchors.right: parent.right
        anchors.rightMargin: 30
        anchors.top: statusImage.top
        anchors.topMargin: -7
        font: fontStyles.dashboardProductStateFont
        color: "black";
        text: context.ProductStateDescription
        elide: Text.ElideRight
    }

    Column
    {
        id: statuses
        anchors.left: stateText.left; anchors.leftMargin: -2
        anchors.right: parent.right; anchors.rightMargin: 20
        anchors.top: stateText.bottom
        anchors.topMargin: 8
        spacing: 1
        property real infoRowHeight: (statusImage.height * 0.7) / 5

        InfoRow // Active threats
        {
            itemId : "ThreatsState"
            value : context.ThreatsStateDescription
            height : statuses.infoRowHeight
        }

        InfoRow // Protection components
        {
            itemId : "ProtectionState"
            value : context.ProtectionStateDescription
            height : statuses.infoRowHeight
        }

        InfoRow // Bases
        {
            itemId : "BasesState"
            value : context.BasesStateDescription
            height : statuses.infoRowHeight
        }

        InfoRow // subscription
        {
            visible: context.IsSubscriptionLicense
            itemId : "SubscriptionState"
            stateId : "LicenseState"
            value : context.LicenseStateDescription
            height : statuses.infoRowHeight
        }

        InfoRow // Licenses
        {
            visible: !context.IsSubscriptionLicense
            itemId : "LicenseState"
            stateId : "LicenseState"
            value : context.LicenseStateDescription
            height : statuses.infoRowHeight
        }

        InfoRow // Recommendations
        {
            itemId : "RecommendationsState"
            value : context.RecommendationsStateDescription
            visible: context.HasRecommendations;
            height : statuses.infoRowHeight
        }
    }
}
