import Qt 4.7
import "../common/widgets" as Widgets
import "../common/fonts" as Fonts
import "SearchListItems.js" as SearchListItems
import "../common/EnumHelper.js" as EnumHelper

InnerContent
{
    id: searchPanel
    unloadable: false
    property int helpId: 44623
    caption: MainWindow.Localize("SearchResults")

    function updateSearchList(text)
    {
        getViewAreaItem().updateSearchList(text)
    }

    function onShow()
    {
        showSearchBox()
    }
    function onHide()
    {
        hideSearchBox()
    }
    function showSearchBox()
    {
        moveSearch.state="Show"
    }
    function hideSearchBox()
    {
        moveSearch.state="Hide"
    }

    viewArea: Component
    {
        id: searchComponent
        Item
        {
            property variant fontStyles: Fonts.Fonts{}
            property variant commonFontStyles: Fonts.Common{}
            property variant context: MainWindow

            property bool noSearchResults: false

			function checkTextForSearchKeys(datum, text)
			{
				var searchKeys = (context.Localize(datum.listItem) + (datum.searchKeys ? (" " + context.Localize(datum.searchKeys)) : "")).toLowerCase();
				if (!searchKeys)
					return;
				var strings = text.toLowerCase().split(" ");
				for (var i = 0; i != strings.length; ++i)
				{
					var searchSubstr = strings[i];
					if (searchKeys.search(searchSubstr) == -1)
						return false;
				}
				return true;
			}
            function updateSearchListFromDataArray(data, text)
            {
                var lastImageSource = (searchListModel.count != 0) ? searchListModel.get(searchListModel.count-1).imageSource : ""
                for (var index in data)
                {
                    var datum = data[index];
                    var itemText = context.Localize(datum.listItem);
                    if (itemText.length && (text == "*" || checkTextForSearchKeys(datum, text)))
                    {
                        datum.firstInGroup = datum.imageSource != lastImageSource;
                        searchListModel.append(datum);
                        if (datum.firstInGroup)
				lastImageSource = datum.imageSource;
                    }
                }
            }
            function updateSearchList(text)
            {
                searchListModel.clear();
                if (!text || text == "")
                {
                    noSearchResults = false;
                    return;
                }

                updateSearchListFromDataArray(SearchListItems.generalSearchData, text);
                switch(EnumHelper.getKey(context, "productType"))
                {
                    case "KasperskyInternetSecurity":
                    {
                        updateSearchListFromDataArray(SearchListItems.kisSpecificSearchData,text);
                        updateSearchListFromDataArray(SearchListItems.kisSpecificSettingsSearchData,text);
                        break;
                    }
                    case "KasperskyAntiVirus":
                        updateSearchListFromDataArray(SearchListItems.kavSpecificSearchData,text);
                        break;
                }
                updateSearchListFromDataArray(SearchListItems.settingsSearchData, text);
                noSearchResults = searchListModel.count == 0
            }

            Widgets.EmptyListText
            {
                visible: noSearchResults
                text: context.Localize("EmptySearchResults")
            }

            Item
            {
                id: searchlist
                anchors.fill: parent
                visible: searchListView.count > 0

                ListModel
                {
                        id: searchListModel
                }

                ListView
                {
                        id: searchListView
                        anchors.fill: parent
                        model : searchListModel
                        clip: true
                        delegate : Item
                        {
                                id: row
                                height: 60
                                width: parent.width

                                Item
                                {
                                    clip: !firstInGroup
                                    anchors.fill: parent
                                    anchors.leftMargin: verticalSeparator.x
                                    Image
                                    {
                                        x: -parent.x
                                        source: "../common/images/inner/list_separator.png"
                                        anchors.top: parent.top
                                        width: parent.width - x
                                    }
                                }
                                Image
                                {
                                    id: imageSearchItem
                                    x: 10
                                    anchors.verticalCenter: parent.verticalCenter
                                    source: imageSource
                                    visible: firstInGroup
                                }

                                Rectangle
                                {
                                    id: verticalSeparator
                                    height: parent.height
                                    width: 1
                                    color: "#dddddd"
                                    anchors.left: imageSearchItem.right
                                    anchors.leftMargin: 10
                                }

                                Text
                                {
                                    text: context.Localize(listItem)
                                    anchors.left: verticalSeparator.right
                                    anchors.verticalCenter: parent.verticalCenter
                                    font: commonFontStyles.standardSmallCaptionFont
                                    anchors.leftMargin: 10
                                }

                                MouseArea
                                {
                                        anchors.fill: row
                                        hoverEnabled:	parent.enabled
                                        onClicked:
                                        {
                                        	if (panel != undefined)
                                                searchPanel.activate(panel)
                                            else if (oldAction != undefined)
                                                MainWindow.InvokeSkinAction(oldAction);
                                        }
                                        Widgets.Clickable {}
                                }
                        }
                        footer: Image
                        {
                            source: "../common/images/inner/list_separator.png"
                            width: parent.width
                        }
                }
                Widgets.FlickableScrollBar
                {
                    target: searchListView
                    height: searchListView.height - 10
                    anchors
                    {
                        verticalCenter: searchListView.verticalCenter
                        right: searchListView.right
                        rightMargin: 5
                    }
                }

            }
        }
    }
}



