import Qt 4.7
import "../common/widgets" as Widgets
import "../common/fonts" as Fonts
import "../common/border" as Border

Border.BorderedContent
{
	objectName:	"safeBrowserSettings"
    content: dialog
    Widgets.SecondaryWindow
    {
        id: dialog
        objectName: "SettingsSafeBrowserDialog"
        property variant context: SafeBrowserSettings
        property variant standartFontStyles: Fonts.Common{}

        width:	420
        height: 450

        Widgets.DPIScaler { changeHeight: true }

        caption: context.Localize("SafeBrowseSettingsCaption")
        workArea : Item
        {
            id: mainArea
            objectName:	"mainArea"
            anchors.fill: parent
            anchors.topMargin:	30
            anchors.leftMargin: 30
            anchors.rightMargin: 30
            Column
            {
                anchors.fill: parent
                spacing: 25
                objectName:	"column"
                Column
                {
                    width: parent.width
                    spacing: 10
                    objectName:	"column"
                    Text
                    {
                        width: parent.width
                        text: dialog.context.Localize("SafeBrowserSelectionText")
                        wrapMode: "WordWrap"
                        font: dialog.standartFontStyles.standardBoldSubHeadingFont
                        lineHeight: 0.9
                    }

                    Widgets.ComboBox
                    {
						objectName:	"defaultBrowser"
                        property QtObject tempElement
                        property QtObject defaultBrowser: dialog.context.DefaultBrowser

                        Component.onCompleted:
                        {
                            defaultIconSource = "image://safebrowsersettings/" + defaultBrowser.iconSource;
                            defaultText = defaultBrowser.name;
                        }

                        width: parent.width
                        actionList: dialog.context.AvailableBrowsersList
                        onPressed:
                        {
                            tempElement = actionList[index];
                            if(tempElement.action != undefined)
                            {
                                tempElement.action.Invoke();
                                defaultText = defaultBrowser.name;
                                defaultIconSource = "image://safebrowsersettings/" + defaultBrowser.iconSource;
                            }
                        }
                    }
                }
                Column
                {
                    width: parent.width
                    spacing: 10
                    objectName:	"autoClean"

                    Widgets.RadioGroup		{id: selectionForSettings}
                    Text
                    {
                        id: safeBrowserSettingsHeader
                        text: dialog.context.Localize("SafeBrowserSettingsHeaderText")
                        font: dialog.standartFontStyles.standardBoldSubHeadingFont
                    }
                    Item
                    {
                        height: childrenRect.height
                        width: parent.width
                        objectName:	"selectionTurnAutoCleanItem"
                        Widgets.RadioButton
                        {
                            id:					selectionTurnAutoClean
                            objectName:	"selectionTurnAutoClean"
                            anchors.left:		parent.left
                            anchors.right:		parent.right
                            color: 				"transparent"
                            horizontalMargin:	7
                            text:				dialog.context.Localize("SelectionTurnAutoClean")
                            checked:			dialog.context.AutoCleanup
                            group:				selectionForSettings

                            onCheckedChanged: dialog.context.AutoCleanup = checked

                            Component.onCompleted: checked = dialog.context.AutoCleanup
                        }
                        Text
                        {
                            id: selectionTurnAutoCleanDescription
                            text: dialog.context.Localize("SelectionTurnAutoCleanDescription")
                            font: dialog.standartFontStyles.standardCommonTextFont
                            width: parent.width - 21
                            wrapMode: "WordWrap"
                            anchors.right: parent.right
                            anchors.top: selectionTurnAutoClean.bottom
                            anchors.topMargin: 2
                        }

                    }
                    Item
                    {
                        height: childrenRect.height
                        width: parent.width
                        objectName:	"selectionTurnOffAutoCleanItem"
                        Widgets.RadioButton
                        {
                            id:					selectionTurnOffAutoClean
                            objectName:	"selectionTurnOffAutoClean"
                            anchors.left:		parent.left
                            anchors.right:		parent.right
                            color: 				"transparent"
                            horizontalMargin:	7
                            text:				dialog.context.Localize("SelectionTurnOffAutoClean")
                            group:				selectionForSettings

                            Component.onCompleted: checked = !dialog.context.AutoCleanup
                        }
                        Text
                        {
                            id: selectionTurnOffAutoCleanDescription
                            text: dialog.context.Localize("SelectionTurnOffAutoCleanDescription")
                            font: dialog.standartFontStyles.standardCommonTextFont
                            width: parent.width - 21
                            wrapMode: "WordWrap"
                            anchors.right: parent.right
                            anchors.top: selectionTurnOffAutoClean.bottom
                            anchors.topMargin: 2
                        }
                    }
                }
            }
        }

        buttonsArea : Item
        {
			objectName:	"buttonsArea"
            Widgets.HelpButton
            {
                x: 10
                objectName: "SettingsSafeBrowser_HelpButton"
                context: dialog.context
                onClicked: { Help.Show(44963); }
                anchors.verticalCenter: parent.verticalCenter
                anchors.left: parent.left
            }

            Row
            {
                spacing: 8
                height: parent.height
                anchors.right: parent.right;
                objectName:	"buttonsRow"

                Widgets.GrayButton
                {
                    objectName: "SettingsSafeBrowser_SaveButton"
                    text: dialog.context.Localize("SaveButton");
                    onClicked:
                    {
                        dialog.context.SaveSettings();
                        Window.Close();
                    }
                    verticalMargin: 10
                    horizontalMargin: 20
                    anchors.verticalCenter: parent.verticalCenter
                    enabled: dialog.context.SettingsModified
                }

                Widgets.GrayButton
                {
                    objectName: "SettingsSafeBrowser_CancelButton"
                    text: dialog.context.Localize("Cancel");
                    onClicked: { Window.Close() }
                    anchors.verticalCenter: parent.verticalCenter
                    verticalMargin: 10
                    horizontalMargin: 20
                }
            }
        }
    }
}
